Clazz.declarePackage("JS");
(function(){
var c$ = Clazz.declareType(JS, "SwingConstants", null);
})();
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
